Stan Math Library: stan/math/prim/scal/fun/logical_or.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

logical_or.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_LOGICAL_OR_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_LOGICAL_OR_HPP
3
4 namespace stan {
5 namespace math {
6
27 template <typename T1, typename T2>
28 inline int
29 logical_or(T1 x1, T2 x2) {
30 return (x1 != 0) || (x2 != 0);
31 }
32
33 }
34 }
35
36 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::logical_or
int logical_or(T1 x1, T2 x2)
The logical or function which returns 1 if either argument is unequal to zero and 0 otherwise...
Definition: logical_or.hpp:29

[ Stan Home Page ] © 2011–2016, Stan Development Team.